@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ our @EXPORT = qw(apache_init apache_update apache_cgi);
 #
 # Some ideas of this upgrading function have been taken from a script written
 # by Joost Cassee and found in the RRDtool Contrib Area:
-# <http://oss.oetiker.ch/rrdtool/pub/contrib/>
+# <https://oss.oetiker.ch/rrdtool/pub/contrib/>
 #
 sub upgrade_to_380 {
 	my $myself = (caller(0))[3];
@@ -733,6 +733,7 @@ sub apache_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my @IMG;
 	my @IMGz;
@@ -752,6 +753,9 @@ sub apache_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -765,9 +769,9 @@ sub apache_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $line1;
@@ -894,6 +898,7 @@ sub apache_cgi {
 			"--vertical-label=Workers",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -918,6 +923,7 @@ sub apache_cgi {
 				"--vertical-label=Workers",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1021,6 +1027,7 @@ sub apache_cgi {
 			"--vertical-label=Workers",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1047,6 +1054,7 @@ sub apache_cgi {
 				"--vertical-label=Workers",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1117,6 +1125,7 @@ sub apache_cgi {
 			"--vertical-label=Percent (%)",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1137,6 +1146,7 @@ sub apache_cgi {
 				"--vertical-label=Percent",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1199,6 +1209,7 @@ sub apache_cgi {
 			"--vertical-label=Requests/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1219,6 +1230,7 @@ sub apache_cgi {
 				"--vertical-label=Requests/s",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1288,6 +1300,7 @@ sub apache_cgi {
 			"--vertical-label=Workers",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1311,6 +1324,7 @@ sub apache_cgi {
 				"--vertical-label=Workers",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1376,6 +1390,7 @@ sub apache_cgi {
 			"--vertical-label=Slots",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1396,6 +1411,7 @@ sub apache_cgi {
 				"--vertical-label=Slots",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
