@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -395,7 +395,7 @@ sub fs_init {
 						}
 					};
 					alarm($config->{timeout});
-					$pid = open(IN, "df -P $f |");
+					$pid = open(IN, "df -P '$f' |");
 					while(<IN>) {
 						if(/ $f$/) {
 							($d) = split(' ', $_);
@@ -638,7 +638,7 @@ sub fs_update {
 						@tmp = (0, 0, 0, 0);
 					};
 					alarm($config->{timeout});
-					$pid = open(IN, "df -P $f |");
+					$pid = open(IN, "df -P '$f' |");
 					while(<IN>) {
 						if(/ $f$/) {
 							@tmp = split(' ', $_);
@@ -665,9 +665,9 @@ sub fs_update {
 					};
 					alarm($config->{timeout});
 					if($config->{os} eq "Linux") {
-						$pid = open(IN, "df -P -i $f |");
+						$pid = open(IN, "df -P -i '$f' |");
 					} elsif($config->{os} eq "FreeBSD" || $config->{os} eq "OpenBSD") {
-						$pid = open(IN, "df -i $f |");
+						$pid = open(IN, "df -i '$f' |");
 					}
 					while(<IN>) {
 						if(/ $f$/) {
@@ -745,7 +745,7 @@ sub fs_update {
 						$write_sec =~ s/\).*$//;
 					}
 				} elsif($config->{os} eq "FreeBSD") {
-					@tmp = split(' ', `iostat -xI $d | grep -w $d`);
+					@tmp = split(' ', `iostat -xI '$d' | grep -w '$d'`);
 					if(@tmp) {
 						(undef, $read_cnt, $write_cnt, $read_sec, $write_sec) = @tmp;
 						$read_cnt = int($read_cnt);
@@ -823,6 +823,7 @@ sub fs_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my $graph_title;
 	my $vlabel;
 	my @IMG;
@@ -854,6 +855,9 @@ sub fs_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -867,9 +871,9 @@ sub fs_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $line1;
@@ -1009,6 +1013,7 @@ sub fs_cgi {
 			"--vertical-label=Percent (%)",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1035,6 +1040,7 @@ sub fs_cgi {
 				"--vertical-label=Percent (%)",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1125,6 +1131,7 @@ sub fs_cgi {
 			"--vertical-label=Reads+Writes/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1151,6 +1158,7 @@ sub fs_cgi {
 				"--vertical-label=Reads+Writes/s",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1238,6 +1246,7 @@ sub fs_cgi {
 			"--vertical-label=Percent (%)",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1264,6 +1273,7 @@ sub fs_cgi {
 				"--vertical-label=Percent (%)",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1389,6 +1399,7 @@ sub fs_cgi {
 			"--vertical-label=$vlabel",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1423,6 +1434,7 @@ sub fs_cgi {
 				"--vertical-label=$vlabel",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
