@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2019 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -248,14 +248,14 @@ sub mail_update {
 
 		for my $path (split /:/, $ENV{PATH}) {
 			if(-f "$path/pflogsumm" && -x _) {
-				if(open(IN, "pflogsumm -d today -h 0 -u 0 --smtpd_stats --no_bounce_detail --no_deferral_detail --no_reject_detail --no_no_msg_size --no_smtpd_warnings $config->{mail_log} 2>/dev/null |")) {
+				if(open(IN, "pflogsumm -d today -h 0 -u 0 --smtpd_stats --bounce_detail=0 --deferral_detail=0 --reject_detail=0 --no_no_msg_size --smtpd_warning_detail=0 $config->{mail_log} 2>/dev/null |")) {
 					@data = <IN>;
 					close(IN);
 					last;
 				}
 			}
 			if(-f "$path/pflogsumm.pl" && -x _) {
-				if(open(IN, "pflogsumm.pl -d today -h 0 -u 0 --smtpd_stats --no_bounce_detail --no_deferral_detail --no_reject_detail --no_no_msg_size --no_smtpd_warnings $config->{mail_log} 2>/dev/null |")) {
+				if(open(IN, "pflogsumm.pl -d today -h 0 -u 0 --smtpd_stats --bounce_detail=0 --deferral_detail=0 --reject_detail=0 --no_no_msg_size --smtpd_warning_detail=0 $config->{mail_log} 2>/dev/null |")) {
 					@data = <IN>;
 					close(IN);
 					last;
@@ -323,7 +323,7 @@ sub mail_update {
 			close(IN);
 		}
 	} elsif(lc($mail->{mta}) eq "exim") {
-		if(open(IN, "eximstats -h0 -ne -nr -t0 /var/log/exim/mainlog |")) {
+		if(open(IN, "eximstats -h0 -ne -nr -t0 $config->{mail_log} |")) {
 			while(<IN>) {
 				if(/^  Received\s+(\d+)(\S\S)\s+(\d+).*?$/) {
 					$bytes_recvd = $1;
@@ -733,6 +733,7 @@ sub mail_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my $T = "B";
 	my $vlabel = "bytes/s";
@@ -752,6 +753,9 @@ sub mail_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -778,9 +782,9 @@ sub mail_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		push(@output, "    <pre style='font-size: 12px; color: $colors->{fg_color}';>\n");
@@ -1082,6 +1086,7 @@ sub mail_cgi {
 		"--vertical-label=$rate_label",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1117,6 +1122,7 @@ sub mail_cgi {
 			"--vertical-label=$rate_label",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1213,6 +1219,7 @@ sub mail_cgi {
 		"--vertical-label=$vlabel",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1237,6 +1244,7 @@ sub mail_cgi {
 			"--vertical-label=$vlabel",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1304,6 +1312,7 @@ sub mail_cgi {
 		"--vertical-label=Messages",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1324,6 +1333,7 @@ sub mail_cgi {
 			"--vertical-label=Messages",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1385,6 +1395,7 @@ sub mail_cgi {
 		"--vertical-label=bytes",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1406,6 +1417,7 @@ sub mail_cgi {
 			"--vertical-label=bytes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1474,6 +1486,7 @@ sub mail_cgi {
 		"--vertical-label=Messages",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1497,6 +1510,7 @@ sub mail_cgi {
 			"--vertical-label=Messages",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1585,6 +1599,7 @@ sub mail_cgi {
 		"--vertical-label=$rate_label",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1608,6 +1623,7 @@ sub mail_cgi {
 			"--vertical-label=$rate_label",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
