@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -209,9 +209,13 @@ sub mongodb_update {
 		my $mongo = trim($ml[$n]);
 		my $host = $mongodb->{desc}->{$mongo}->{host} || "";
 		my $port = $mongodb->{desc}->{$mongo}->{port} || "";
+		my $user = $mongodb->{desc}->{$mongo}->{username} || "";
+		my $pass = $mongodb->{desc}->{$mongo}->{password} || "";
 		my $cmd = "mongo ";
 		$cmd .= "--host $host " if $host;
 		$cmd .= "--port $port " if $port;
+		$cmd .= "-u $user " if $user;
+		$cmd .= "-p $pass " if $pass;
 		$cmd .= "--eval \"printjson(db.serverStatus())\"";
 
 		if(open(IN, "$cmd |")) {
@@ -595,6 +599,7 @@ sub mongodb_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my @IMG;
 	my @IMGz;
@@ -616,6 +621,9 @@ sub mongodb_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -634,9 +642,9 @@ sub mongodb_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $line0;
@@ -828,6 +836,7 @@ sub mongodb_cgi {
 			"--vertical-label=Operations/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -853,6 +862,7 @@ sub mongodb_cgi {
 				"--vertical-label=Operations/s",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -935,6 +945,7 @@ sub mongodb_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -958,6 +969,7 @@ sub mongodb_cgi {
 				"--vertical-label=Values/s",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1027,6 +1039,7 @@ sub mongodb_cgi {
 			"--vertical-label=ms",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1048,6 +1061,7 @@ sub mongodb_cgi {
 				"--vertical-label=ms",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1112,6 +1126,7 @@ sub mongodb_cgi {
 			"--vertical-label=Connections",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1133,6 +1148,7 @@ sub mongodb_cgi {
 				"--vertical-label=Connections",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1197,6 +1213,7 @@ sub mongodb_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1218,6 +1235,7 @@ sub mongodb_cgi {
 				"--vertical-label=Values/s",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1295,6 +1313,7 @@ sub mongodb_cgi {
 			"--vertical-label=$vlabel",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1316,6 +1335,7 @@ sub mongodb_cgi {
 				"--vertical-label=$vlabel",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1410,6 +1430,7 @@ sub mongodb_cgi {
 				"--vertical-label=Values",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1432,6 +1453,7 @@ sub mongodb_cgi {
 					"--vertical-label=Values",
 					"--width=$width",
 					"--height=$height",
+					@extra,
 					@riglim,
 					$zoom,
 					@{$cgi->{version12}},
@@ -1505,6 +1527,7 @@ sub mongodb_cgi {
 				"--vertical-label=bytes",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1527,6 +1550,7 @@ sub mongodb_cgi {
 					"--vertical-label=bytes",
 					"--width=$width",
 					"--height=$height",
+					@extra,
 					@riglim,
 					$zoom,
 					@{$cgi->{version12}},
