@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ sub nfss_init {
 	my @max;
 	my @last;
 
-	if(grep {$_ eq $config->{os}} ("FreeBSD", "OpenBSD", "NetBSD")) {
+	if(grep {$_ eq $config->{os}} ("OpenBSD", "NetBSD")) {
 		logger("$myself is not supported yet by your operating system ($config->{os}).");
 		return;
 	}
@@ -252,6 +252,84 @@ sub nfss_update {
 		}
 	}
 
+	# On FreeBSD run nfsstat(1) to get this info
+	# We want to fill in the @rc, @fh, @io, @th, @net, @rpc, @nfss arrays
+	# with the same types of data (or 0) that linux gets out of /proc
+
+	if($config->{os} eq "FreeBSD") {
+		my $stats = &parse_nfsstat();
+		if (! $stats) {
+			logger("$myself: ERROR: Unable to run and parse output from 'nfsstat'. $!.");
+			return;
+		}
+
+		# Now shove the data into the arrays in the way the rest of
+		# this plugin expects to find them
+
+		# LINUX: @rc = reply cache = (hits, misses, nocache)
+		# FreeBSD: Server Cache Stats: Inprog, idem, Non-idem, Misses
+		@rc = (
+			$stats->{'Idem'}, 
+			$stats->{'Misses'}, 
+			$stats->{'Non-idem'}
+		); 
+
+		# LINUX: @fh = file handles = (stale, total_lookups, anonlookups, dirnocache, nodirnocahe)
+		# FreeBSD: No data
+		@fh = (0,0,0,0,0);
+
+		# LINUX: @io = I/O = (read, wright)
+		# FreeBSD: Server Info: Read, Write
+		@io = (
+			$stats->{'Read'}, 
+			$stats->{'Write'} 
+		);
+
+		# LINUX: @th = Threads = (11 values)
+		# FreeBSD: Server Info: No data
+		@th = (0,0,0,0,0,0,0,0,0,0,0);
+
+		# LINUX: @net = Net = (netcount, udpcount, tcpcount, tcpconnect)
+		# FreeBSD: Server Info: No data
+		@net = (0,0,0,0);
+
+		# LINUX: @rpc = RPC = (count, badcnt, badfmt, badauth, badcInt)
+		# FreeBSD: Server Info: No data
+		@rpc = (0,0,0,0,0);
+
+		# LINUX: @nfss = Server stats = for v3, 22 stats:
+		#   null / getattr / setattr / lookup / access 
+		#   readlink / read / write / create / mkdir / symlink
+		#   mknod / remove / rmdir / rename / link / readdir
+		#   readdirplus / fsstat / fsinfo / pathconf / commit
+		# FreeBSD: Server Info: has all those items with similar names
+		@nfss = (
+			0,
+			$stats->{'Getattr'}, 
+			$stats->{'Setattr'}, 
+			$stats->{'Lookup'}, 
+			$stats->{'Access'}, 
+			$stats->{'Readlink'}, 
+			$stats->{'Read'}, 
+			$stats->{'Write'}, 
+			$stats->{'Create'}, 
+			$stats->{'Mkdir'}, 
+			$stats->{'Symlink'}, 
+			$stats->{'Mknod'}, 
+			$stats->{'Remove'}, 
+			$stats->{'Rmdir'}, 
+			$stats->{'Rename'}, 
+			$stats->{'Link'}, 
+			$stats->{'Readdir'}, 
+			$stats->{'RdirPlus'}, 
+			$stats->{'Fsstat'}, 
+			$stats->{'Fsinfo'}, 
+			$stats->{'PathConf'}, 
+			$stats->{'Commit'} 
+		);
+
+	}
+
 	for($n = 0; $n < 50; $n++) {
 		if(!defined($nfss[$n])) {
 			$nfss[$n] = 0;
@@ -297,6 +375,7 @@ sub nfss_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my @tmp;
 	my @tmpz;
@@ -337,6 +416,9 @@ sub nfss_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	my @nfsv2 = ("null", "getattr", "setattr", "root", "lookup", "readlink", "read", "wrcache", "write", "create", "remove", "rename", "link", "symlink", "mkdir", "rmdir", "readdir", "fsstat");
 	my @nfsv3 = ("null", "getattr", "setattr", "lookup", "access", "readlink", "read", "write", "create", "mkdir", "symlink", "mknod", "remove", "rmdir", "rename", "link", "readdir", "readdirplus", "fsstat", "fsinfo", "pathconf", "commit");
@@ -366,9 +448,9 @@ sub nfss_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $str;
@@ -529,6 +611,7 @@ sub nfss_cgi {
 		"--vertical-label=Requests/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -548,6 +631,7 @@ sub nfss_cgi {
 			"--vertical-label=Requests/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -623,6 +707,7 @@ sub nfss_cgi {
 		"--vertical-label=Requests/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -641,6 +726,7 @@ sub nfss_cgi {
 			"--vertical-label=Requests/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -716,6 +802,7 @@ sub nfss_cgi {
 		"--vertical-label=Requests/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -734,6 +821,7 @@ sub nfss_cgi {
 			"--vertical-label=Requests/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -804,6 +892,7 @@ sub nfss_cgi {
 		"--vertical-label=bytes/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -825,6 +914,7 @@ sub nfss_cgi {
 			"--vertical-label=bytes/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -897,6 +987,7 @@ sub nfss_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -920,6 +1011,7 @@ sub nfss_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -994,6 +1086,7 @@ sub nfss_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1018,6 +1111,7 @@ sub nfss_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1111,6 +1205,7 @@ sub nfss_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1141,6 +1236,7 @@ sub nfss_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1222,6 +1318,7 @@ sub nfss_cgi {
 		"--vertical-label=Requests/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1244,6 +1341,7 @@ sub nfss_cgi {
 			"--vertical-label=Requests/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1317,6 +1415,7 @@ sub nfss_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1341,6 +1440,7 @@ sub nfss_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1385,4 +1485,43 @@ sub nfss_cgi {
 	return @output;
 }
 
+# Returns a hashref full of server stats, or undef if anything went wrong
+sub parse_nfsstat {
+	my @heads;
+	my @values;
+	my $head;
+	my $val;
+	my $line;
+	my $stats;
+	my $i;
+
+	if(! open(IN, "nfsstat -s |")) {
+		return undef;
+	}
+	while(<IN>) {
+		next if (/:/);		# Skip section heads
+		next if (/^\s*$/);	# Skip blank lines
+		s/^\s+//;		# Nuke leading spaces
+		if (/[a-z]+\s+[a-z]+/i) {
+			# This looks like a header line
+			@heads = split(/\s+/, $_);
+			# Pull the next line of data
+			$line = <IN>;
+			$line =~ s/^\s+//;	# Nuke leading spaces
+			$line =~ s/Server /Server_/;	# Fix multiword
+			@values = split(/\s+/, $line);
+			for ($i = 0; $i <= $#values; $i++) {
+				$val = $values[$i];
+				if ($val < 0) {
+					# Fix overflow?
+					$val += 2**31;
+				}
+				$stats->{$heads[$i]} = $val;
+			}
+		}
+	}
+	close(IN);
+	return $stats;
+}
+
 1;
