@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -129,48 +129,54 @@ sub port_init {
 		logger("$myself: WARNING: 'max' option indicates less ports than really defined in 'list'.");
 	}
 
-	if($config->{os} eq "Linux") {
-		my $num;
-		my @line;
+	if(lc($config->{use_external_firewall} || "") eq "n") {
+		if($config->{os} eq "Linux") {
+			my $num;
+			my @line;
 
-		# set the iptables rules for each defined port
-		my @pl = split(',', $port->{list});
-		for($n = 0; $n < min($port->{max}, scalar(@pl)); $n++) {
-			$pl[$n] = trim($pl[$n]);
-			my ($np) = ($pl[$n] =~ m/^(\d+).*?/);
+			# set the iptables rules for each defined port
+			my @pl = split(',', $port->{list});
+			for($n = 0; $n < min($port->{max}, scalar(@pl)); $n++) {
+				$pl[$n] = trim($pl[$n]);
+				my ($np) = ($pl[$n] =~ m/^(\d+).*?/);
 
-			if(!$port->{desc}->{$pl[$n]}) {
-				logger("$myself: port number '$np' listed but not defined.");
-				next;
-			}
-			if($pl[$n] && $np) {
-				my $p = trim(lc((split(',', $port->{desc}->{$pl[$n]}))[1])) || "";
-				if(! grep {$_ eq $p} ("tcp", "udp", "tcp6", "udp6")) {
-					logger("$myself: Invalid protocol name '$p' in port '$pl[$n]'.");
+				if(!$port->{desc}->{$pl[$n]}) {
+					logger("$myself: port number '$np' listed but not defined.");
 					next;
 				}
-				$cmd = "iptables" . $config->{iptables_wait_lock};
-				if(grep {$_ eq $p} ("tcp6", "udp6")) {
-					if(lc($config->{ipv6_disabled} || "") eq "y") {
-						logger("$myself: IPv6 is explicitly disabled, you shouldn't want to monitor 'tcp6' or 'udp6' protocols.");
+				# support for port range (i.e: 49152:65534)
+				if(index($pl[$n], ":") != -1) {
+					($np) = ($pl[$n] =~ m/^(\d+:\d+).*?/);
+				}
+				if($pl[$n] && $np) {
+					my $p = trim(lc((split(',', $port->{desc}->{$pl[$n]}))[1])) || "";
+					if(! grep {$_ eq $p} ("tcp", "udp", "tcp6", "udp6")) {
+						logger("$myself: Invalid protocol name '$p' in port '$pl[$n]'.");
 						next;
 					}
-					$cmd = "ip6tables" . $config->{iptables_wait_lock};
-					$p =~ s/6//;
-				}
-				my $conn = trim(lc((split(',', $port->{desc}->{$pl[$n]}))[2]));
-				if($conn eq "in" || $conn eq "in/out") {
-					system("$cmd -t $table -N monitorix_IN_$n 2>/dev/null");
-					system("$cmd -t $table -I INPUT -p $p --sport 1024:65535 --dport $np -m conntrack --ctstate NEW,ESTABLISHED,RELATED -j monitorix_IN_$n -c 0 0");
-					system("$cmd -t $table -I OUTPUT -p $p --sport $np --dport 1024:65535 -m conntrack --ctstate ESTABLISHED,RELATED -j monitorix_IN_$n -c 0 0");
-				}
-				if($conn eq "out" || $conn eq "in/out") {
-					system("$cmd -t $table -N monitorix_OUT_$n 2>/dev/null");
-					system("$cmd -t $table -I INPUT -p $p --sport $np --dport 1024:65535 -m conntrack --ctstate ESTABLISHED,RELATED -j monitorix_OUT_$n -c 0 0");
-					system("$cmd -t $table -I OUTPUT -p $p --sport 1024:65535 --dport $np -m conntrack --ctstate NEW,ESTABLISHED,RELATED -j monitorix_OUT_$n -c 0 0");
-				}
-				if($conn ne "in" && $conn ne "out" && $conn ne "in/out") {
-					logger("$myself: Invalid connection type '$conn'; must be 'in', 'out' or 'in/out'.");
+					$cmd = "iptables" . $config->{iptables_wait_lock};
+					if(grep {$_ eq $p} ("tcp6", "udp6")) {
+						if(lc($config->{ipv6_disabled} || "") eq "y") {
+							logger("$myself: IPv6 is explicitly disabled, you shouldn't want to monitor 'tcp6' or 'udp6' protocols.");
+							next;
+						}
+						$cmd = "ip6tables" . $config->{iptables_wait_lock};
+						$p =~ s/6//;
+					}
+					my $conn = trim(lc((split(',', $port->{desc}->{$pl[$n]}))[2]));
+					if($conn eq "in" || $conn eq "in/out") {
+						system("$cmd -t $table -N monitorix_IN_$n 2>/dev/null");
+						system("$cmd -t $table -I INPUT -p $p --sport 1024:65535 --dport $np -m conntrack --ctstate NEW,ESTABLISHED,RELATED -j monitorix_IN_$n -c 0 0");
+						system("$cmd -t $table -I OUTPUT -p $p --sport $np --dport 1024:65535 -m conntrack --ctstate ESTABLISHED,RELATED -j monitorix_IN_$n -c 0 0");
+					}
+					if($conn eq "out" || $conn eq "in/out") {
+						system("$cmd -t $table -N monitorix_OUT_$n 2>/dev/null");
+						system("$cmd -t $table -I INPUT -p $p --sport $np --dport 1024:65535 -m conntrack --ctstate ESTABLISHED,RELATED -j monitorix_OUT_$n -c 0 0");
+						system("$cmd -t $table -I OUTPUT -p $p --sport 1024:65535 --dport $np -m conntrack --ctstate NEW,ESTABLISHED,RELATED -j monitorix_OUT_$n -c 0 0");
+					}
+					if($conn ne "in" && $conn ne "out" && $conn ne "in/out") {
+						logger("$myself: Invalid connection type '$conn'; must be 'in', 'out' or 'in/out'.");
+					}
 				}
 			}
 		}
@@ -345,6 +351,7 @@ sub port_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my @warning;
 	my @IMG;
@@ -367,6 +374,9 @@ sub port_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -385,9 +395,9 @@ sub port_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $line1;
@@ -526,7 +536,7 @@ sub port_cgi {
 
 			# check if the network port is still listening
 			undef(@warning);
-			if(uc($plis) eq "L") {
+			if(uc($plis || "") eq "L") {
 				if($config->{os} eq "Linux") {
 					open(IN, "netstat -nl --$pp |");
 					while(<IN>) {
@@ -627,6 +637,7 @@ sub port_cgi {
 				"--vertical-label=$vlabel",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -651,6 +662,7 @@ sub port_cgi {
 					"--vertical-label=$vlabel",
 					"--width=$width",
 					"--height=$height",
+					@extra,
 					@riglim,
 					$zoom,
 					@{$cgi->{version12}},
