@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -162,7 +162,7 @@ sub process_update {
 			my $ics = 0;
 
 			my $str;
-			my @pid;
+			my @pids;
 			my $p = trim($lp[$n] || "");
 			my $val;
 			my $s_usage = 0;
@@ -172,23 +172,23 @@ sub process_update {
 				while(<IN>) {
 					if(m/^\s*(\d+)\s+(\S+)\s+(.*?)$/) {
 						if($p eq trim($2)) {
-							push(@pid, $1);
+							push(@pids, $1);
 							$pro++;
 							next;
 						}
 						if($p eq trim($3)) {
-							push(@pid, $1);
+							push(@pids, $1);
 							$pro++;
 							next;
 						}
 						if(index($3, $p) != -1) {
-							push(@pid, $1);
+							push(@pids, $1);
 							$pro++;
 							next;
 						}
 					}
 					if(substr($p, 0, 15) eq substr($_, 6, 15)) {
-						push(@pid, $1);
+						push(@pids, $1);
 						$pro++;
 						next;
 					}
@@ -208,8 +208,8 @@ sub process_update {
 			}
 
 			my $p_usage = 0;
-			foreach my $p (@pid) {
-				if(open(IN, "/proc/$p/stat")) {
+			foreach my $pid (@pids) {
+				if(open(IN, "/proc/$pid/stat")) {
 					my $utime = 0;
 					my $stime = 0;
 					my $v_nth = 0;
@@ -219,11 +219,15 @@ sub process_update {
 					# since a process name can include spaces an 'split(' ', <IN>)' wouldn't work here,
 					# therefore we discard the first part of the process information (pid, comm and state).
 					(undef, $rest) = <IN> =~ m/^(\d+\s\(.*?\)\s\S\s)(.*?)$/;
-					(undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, $utime, $stime, undef, undef, undef, undef, $v_nth, undef, undef, undef, $v_mem) = split(' ', $rest);
 					close(IN);
-					$mem += ($v_mem *= 4096);
-					$nth += ($v_nth - 1);
-					$p_usage += $utime + $stime;
+					if($rest) {
+						(undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, $utime, $stime, undef, undef, undef, undef, $v_nth, undef, undef, undef, $v_mem) = split(' ', $rest);
+						$mem += ($v_mem *= 4096);
+						$nth += ($v_nth - 1);
+						$p_usage += $utime + $stime;
+					} else {
+						logger("$myself: WARNING: PID $pid ('$p') has vanished while accounting!");
+					}
 				}
 			}
 			$str = $e . "_cpu" . $n;
@@ -233,8 +237,8 @@ sub process_update {
 
 			my $v_dsk = 0;
 			my $v_net = 0;
-			foreach my $p (@pid) {
-				if(open(IN, "/proc/$p/io")) {
+			foreach my $pid (@pids) {
+				if(open(IN, "/proc/$pid/io")) {
 					my $rchar = 0;
 					my $wchar = 0;
 					my $readb = 0;
@@ -264,14 +268,14 @@ sub process_update {
 
 			my $v_vcs = 0;
 			my $v_ics = 0;
-			foreach my $p (@pid) {
-				if(opendir(DIR, "/proc/$p/fdinfo")) {
+			foreach my $pid (@pids) {
+				if(opendir(DIR, "/proc/$pid/fdinfo")) {
 					my @files = grep { !/^[.]/ } readdir(DIR);
 					$nof += scalar(@files);
 					closedir(DIR);
 				}
 
-				if(open(IN, "/proc/$p/status")) {
+				if(open(IN, "/proc/$pid/status")) {
 					while(<IN>) {
 						if(/^voluntary_ctxt_switches:\s+(\d+)$/) {
 							$v_vcs += $1;
@@ -330,6 +334,7 @@ sub process_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my $graph_title;
 	my @IMG;
 	my @IMGz;
@@ -364,6 +369,9 @@ sub process_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -382,9 +390,9 @@ sub process_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $line1;
@@ -525,6 +533,7 @@ sub process_cgi {
 			"--vertical-label=Percent (%)",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -553,6 +562,7 @@ sub process_cgi {
 				"--vertical-label=Percent (%)",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -636,6 +646,7 @@ sub process_cgi {
 			"--vertical-label=bytes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -674,6 +685,7 @@ sub process_cgi {
 				"--vertical-label=bytes",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -764,6 +776,7 @@ sub process_cgi {
 			"--vertical-label=bytes/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -802,6 +815,7 @@ sub process_cgi {
 				"--vertical-label=bytes/s",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -866,9 +880,9 @@ sub process_cgi {
 			if($p) {
 				$str = trim((split(',', $process->{desc}->{$p} || ""))[0]) || $p;
 				$str =~ s/:/\\:/g;	# escape colons
-				push(@tmpz, "LINE2:m_net" . $n . $LC[$n] . ":$str");
+				push(@tmpz, "LINE2:net" . $n . $LC[$n] . ":$str");
 				$str = sprintf("%-20s", substr($str, 0, 20));
-				push(@tmp, "LINE2:m_net" . $n . $LC[$n] . ":$str");
+				push(@tmp, "LINE2:net" . $n . $LC[$n] . ":$str");
 				push(@tmp, "GPRINT:m_net" . $n . ":LAST:Cur\\: %4.1lfM");
 				push(@tmp, "GPRINT:m_net" . $n . ":MIN:  Min\\: %4.1lfM");
 				push(@tmp, "GPRINT:m_net" . $n . ":MAX:  Max\\: %4.1lfM\\n");
@@ -918,6 +932,7 @@ sub process_cgi {
 			"--vertical-label=$vlabel",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -946,6 +961,7 @@ sub process_cgi {
 				"--vertical-label=$vlabel",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1026,6 +1042,7 @@ sub process_cgi {
 			"--vertical-label=Files",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1054,6 +1071,7 @@ sub process_cgi {
 				"--vertical-label=Files",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1137,6 +1155,7 @@ sub process_cgi {
 			"--vertical-label=Threads",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1165,6 +1184,7 @@ sub process_cgi {
 				"--vertical-label=Threads",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1250,6 +1270,7 @@ sub process_cgi {
 			"--vertical-label=Nonvoluntary + voluntary/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1309,6 +1330,7 @@ sub process_cgi {
 				"--vertical-label=Nonvoluntary + voluntary/s",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
@@ -1423,6 +1445,7 @@ sub process_cgi {
 			"--vertical-label=Processes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1451,6 +1474,7 @@ sub process_cgi {
 				"--vertical-label=Processes",
 				"--width=$width",
 				"--height=$height",
+				@extra,
 				@riglim,
 				$zoom,
 				@{$cgi->{version12}},
