@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -228,16 +228,30 @@ sub squid_update {
 		}
 	}
 	close(IN);
-	foreach my $code (my @sl = split(',', $squid->{graph_0})) {
-		$code = trim($code);
+	my @sl = split(',', $squid->{graph_0});
+	if(scalar(@sl) > 9) {
+		logger("$myself: WARNING: a maximum of 9 values is allowed in 'graph_0' option.");
+	}
+	for($n = 0; $n < 9 && $sl[$n]; $n++) {
+		my $code = trim($sl[$n]);
 		$rrdata .= ":";
 		$rrdata .= defined($g12{$code}) ? int($g12{$code}) : 0;
 	}
-	foreach my $code (my @sl = split(',', $squid->{graph_1})) {
-		$code = trim($code);
+	for(; $n < 9; $n++) {
+		$rrdata .= ":0";
+	}
+	@sl = split(',', $squid->{graph_0});
+	if(scalar(@sl) > 9) {
+		logger("$myself: WARNING: a maximum of 9 values is allowed in 'graph_1' option.");
+	}
+	for($n = 0; $n < 9 && $sl[$n]; $n++) {
+		my $code = trim($sl[$n]);
 		$rrdata .= ":";
 		$rrdata .= defined($g12{$code}) ? int($g12{$code}) : 0;
 	}
+	for(; $n < 9; $n++) {
+		$rrdata .= ":0";
+	}
 	$config->{squid_hist}->{'seek_pos'} = $logsize;
 
 	open(IN, "$squid->{cmd} mgr:counters |");
@@ -467,6 +481,7 @@ sub squid_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my @tmp;
 	my @tmpz;
@@ -511,6 +526,9 @@ sub squid_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -529,9 +547,9 @@ sub squid_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $str;
@@ -758,6 +776,7 @@ sub squid_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -776,6 +795,7 @@ sub squid_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -852,6 +872,7 @@ sub squid_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -870,6 +891,7 @@ sub squid_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -971,6 +993,7 @@ sub squid_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -998,6 +1021,7 @@ sub squid_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1074,6 +1098,7 @@ sub squid_cgi {
 		"--vertical-label=Megabytes",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1098,6 +1123,7 @@ sub squid_cgi {
 			"--vertical-label=Megabytes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1167,6 +1193,7 @@ sub squid_cgi {
 		"--vertical-label=Megabytes",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1191,6 +1218,7 @@ sub squid_cgi {
 			"--vertical-label=Megabytes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1266,6 +1294,7 @@ sub squid_cgi {
 		"--vertical-label=Values/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1288,6 +1317,7 @@ sub squid_cgi {
 			"--vertical-label=Values/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1366,6 +1396,7 @@ sub squid_cgi {
 		"--vertical-label=Reads/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1389,6 +1420,7 @@ sub squid_cgi {
 			"--vertical-label=Reads/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1467,6 +1499,7 @@ sub squid_cgi {
 		"--vertical-label=$vlabel",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1488,6 +1521,7 @@ sub squid_cgi {
 			"--vertical-label=$vlabel",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1564,6 +1598,7 @@ sub squid_cgi {
 		"--vertical-label=$vlabel",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1585,6 +1620,7 @@ sub squid_cgi {
 			"--vertical-label=$vlabel",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
