@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -185,6 +185,7 @@ sub verlihub_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my @tmp;
 	my @tmpz;
@@ -198,6 +199,9 @@ sub verlihub_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -210,7 +214,10 @@ sub verlihub_cgi {
 			push(@output, "    <tr>\n");
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
-		my (undef, undef, undef, $data) = RRDs::fetch("$rrd","--start=-$tf->{nwhen}$tf->{twhen}","AVERAGE","-r $tf->{res}");
+		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
+			"--start=-$tf->{nwhen}$tf->{twhen}",
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		push(@output, "    <pre style='font-size: 12px; color: $colors->{fg_color}';>\n");
@@ -298,6 +305,7 @@ sub verlihub_cgi {
 		"--vertical-label=Users",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -321,6 +329,7 @@ sub verlihub_cgi {
 			"--vertical-label=Users",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -388,6 +397,7 @@ sub verlihub_cgi {
 		"--width=$width",
 		"--height=$height",
 		"--units-exponent=0",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -409,6 +419,7 @@ sub verlihub_cgi {
 			"--width=$width",
 			"--height=$height",
 			"--units-exponent=0",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -471,6 +482,7 @@ sub verlihub_cgi {
 		"--width=$width",
 		"--height=$height",
 		"--units-exponent=0",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -492,6 +504,7 @@ sub verlihub_cgi {
 			"--width=$width",
 			"--height=$height",
 			"--units-exponent=0",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
