@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2017 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -248,6 +248,79 @@ sub zfs_update {
 			}
 		}
 		close(IN);
+	} elsif(grep {$_ eq $config->{os}} ("FreeBSD", "OpenBSD", "NetBSD")) {
+		# On BSD we get this data from sysctl instead of /proc
+		my $zstat = {};
+		open(SYS, "/sbin/sysctl -q kstat.zfs |");
+		while(<SYS>) {
+			my $var;
+			my $val;
+			chomp;
+			if (m/^([^:]+):\s+(\d+)$/) {
+				($var,$val) = ($1,$2);
+				$zstat->{$var} = $val;
+			}
+		}
+		close(SYS);
+
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.size"}) {
+			$arcsize = $zstat->{"kstat.zfs.misc.arcstats.size"};
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.c_max"}) {
+			$cmax = $zstat->{"kstat.zfs.misc.arcstats.c_max"};
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.c_min"}) {
+			$cmin = $zstat->{"kstat.zfs.misc.arcstats.c_min"};
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.c"}) {
+			$arctgtsize = $zstat->{"kstat.zfs.misc.arcstats.c"};
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.arc_meta_limit"}) {
+			$metalimit = $zstat->{"kstat.zfs.misc.arcstats.arc_meta_limit"};
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.arc_meta_used"}) {
+			$metaused = $zstat->{"kstat.zfs.misc.arcstats.arc_meta_used"};
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.arc_meta_max"}) {
+			$metamax = $zstat->{"kstat.zfs.misc.arcstats.arc_meta_max"};
+		}
+
+		my $tmp;
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.hits"}) {
+			$tmp = $zstat->{"kstat.zfs.misc.arcstats.hits"};
+			$archits = $tmp - ($config->{zfs_hist}->{archits} || 0);
+			$archits = 0 unless $archits != $tmp;
+			$archits /= 60;
+			$config->{zfs_hist}->{archits} = $tmp;
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.misses"}) {
+			$tmp = $zstat->{"kstat.zfs.misc.arcstats.misses"};
+			$arcmisses = $tmp - ($config->{zfs_hist}->{arcmisses} || 0);
+			$arcmisses = 0 unless $arcmisses != $tmp;
+			$arcmisses /= 60;
+			$config->{zfs_hist}->{arcmisses} = $tmp;
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.deleted"}) {
+			$tmp = $zstat->{"kstat.zfs.misc.arcstats.deleted"};
+			$arcdeleted = $tmp - ($config->{zfs_hist}->{arcdeleted} || 0);
+			$arcdeleted = 0 unless $arcdeleted != $tmp;
+			$arcdeleted /= 60;
+			$config->{zfs_hist}->{arcdeleted} = $tmp;
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.l2_hits"}) {
+			$tmp = $zstat->{"kstat.zfs.misc.arcstats.l2_hits"};
+			$l2arc_hits = $tmp - ($config->{zfs_hist}->{l2arc_hits} || 0);
+			$l2arc_hits = 0 unless $l2arc_hits != $tmp;
+			$l2arc_hits /= 60;
+			$config->{zfs_hist}->{l2arc_hits} = $tmp;
+		}
+		if (defined $zstat->{"kstat.zfs.misc.arcstats.l2_misses"}) {
+			$tmp = $zstat->{"kstat.zfs.misc.arcstats.l2_misses"};
+			$l2arc_misses = $tmp - ($config->{zfs_hist}->{l2arc_misses} || 0);
+			$l2arc_misses = 0 unless $l2arc_misses != $tmp;
+			$l2arc_misses /= 60;
+			$config->{zfs_hist}->{l2arc_misses} = $tmp;
+		}
 	}
 
 	$rrdata .= ":$arcsize:$cmax:$cmin:$arctgtsize:$metalimit:$metaused:$metamax:$archits:$arcmisses:$arcdeleted:$l2arc_hits:$l2arc_misses:0:0:0:0:0:0:0:0:0:0";
@@ -256,6 +329,8 @@ sub zfs_update {
 		my $free = 0;
 		my $udata = 0;
 		my $usnap = 0;
+		my $usnapcmd = '';
+		my $iostatcmd = '';
 		my $cap = 0;
 		my $fra = 0;
 		my $oper = 0;
@@ -267,13 +342,27 @@ sub zfs_update {
 		my $pool = (split(',', $zfs->{list}))[$n] || "";
 		if($pool) {
 			my @zpool;
+			my @data;
+
+			if(grep {$_ eq $config->{os}} ("FreeBSD", "OpenBSD", "NetBSD")) {
+				# BSD does not have -tfilesystem for zfs get, so grep out nonsense lines
+				$usnapcmd = "zfs get -rHp -o value usedbysnapshots $pool | grep -v ^-";
+				# BSD zfs iostat does not have -p or -H
+				$iostatcmd = "zpool iostat $pool 5 2";
+			} else {
+				$usnapcmd = "zfs get -rHp -o value usedbysnapshots -tfilesystem $pool";
+				$iostatcmd = "zpool iostat -Hp $pool 5 2";
+			}
 
 			$free = trim(`zfs get -Hp -o value available $pool`);
 			$udata = trim(`zfs get -Hp -o value used $pool`);
-			$usnap = eval join('+',`zfs get -rHp -o value usedbysnapshots -tfilesystem $pool`);
+			$usnap = eval join('+',`$usnapcmd`);
 			@zpool = split(' ', `zpool list -H $pool` || "");
 
-			if(scalar(@zpool) == 10) {	# ZFS version 0.6.4+
+			if(scalar(@zpool) > 10) {	# ZFS version 0.8.0+
+				$cap = trim($zpool[7]);
+				$fra = trim($zpool[6]);
+			} elsif(scalar(@zpool) == 10) {	# ZFS version 0.6.4+
 				$cap = trim($zpool[6]);
 				$fra = trim($zpool[5]);
 			} elsif(scalar(@zpool) == 8) {	# ZFS version 0.6.3- (?)
@@ -282,8 +371,18 @@ sub zfs_update {
 			}
 			$cap =~ s/%//;
 			$fra =~ s/[%-]//g; $fra = $fra || 0;
-			@zpool = split(' ', `zpool iostat -Hp $pool` || "");
-			(undef, undef, undef, $oper, $opew, $banr, $banw) = @zpool;
+
+			open(IN, "$iostatcmd |");
+			while(<IN>) {
+				push(@data, $_);
+			}
+			close(IN);
+			(undef, undef, undef, $oper, $opew, $banr, $banw) = split(' ', pop @data);
+
+			if(grep {$_ eq $config->{os}} ("FreeBSD", "OpenBSD", "NetBSD")) {
+				# lack of -p means we need to fix these values
+				($oper, $opew, $banr, $banw) = &zfs_uglify_numbers("$oper", "$opew", "$banr", "$banw");
+			}
 		}
 
 		$rrdata .= ":$free:$udata:$usnap:$cap:$fra:$oper:$opew:$banr:$banw:0";
@@ -320,6 +419,7 @@ sub zfs_cgi {
 	my $u = "";
 	my $width;
 	my $height;
+	my @extra;
 	my @riglim;
 	my @IMG;
 	my @IMGz;
@@ -337,6 +437,9 @@ sub zfs_cgi {
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
 	my $imgfmt_uc = uc($config->{image_format});
 	my $imgfmt_lc = lc($config->{image_format});
+	foreach my $i (split(',', $config->{rrdtool_extra_options} || "")) {
+		push(@extra, trim($i)) if trim($i);
+	}
 
 	$title = !$silent ? $title : "";
 
@@ -350,9 +453,9 @@ sub zfs_cgi {
 			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=$tf->{res}",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
-			"AVERAGE",
-			"-r $tf->{res}");
+			"AVERAGE");
 		$err = RRDs::error;
 		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $line0;
@@ -511,6 +614,7 @@ sub zfs_cgi {
 		"--vertical-label=bytes",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -537,6 +641,7 @@ sub zfs_cgi {
 			"--vertical-label=bytes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -611,6 +716,7 @@ sub zfs_cgi {
 		"--vertical-label=Reads/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -633,6 +739,7 @@ sub zfs_cgi {
 			"--vertical-label=Reads/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -697,6 +804,7 @@ sub zfs_cgi {
 		"--vertical-label=Reads/s",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -718,6 +826,7 @@ sub zfs_cgi {
 			"--vertical-label=Reads/s",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -794,6 +903,7 @@ sub zfs_cgi {
 		"--vertical-label=bytes",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -816,6 +926,7 @@ sub zfs_cgi {
 			"--vertical-label=bytes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -881,6 +992,7 @@ sub zfs_cgi {
 		"--vertical-label=Percent (%)",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -902,6 +1014,7 @@ sub zfs_cgi {
 			"--vertical-label=Percent (%)",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -970,6 +1083,7 @@ sub zfs_cgi {
 		"--vertical-label=Number",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -992,6 +1106,7 @@ sub zfs_cgi {
 			"--vertical-label=Number",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1057,6 +1172,7 @@ sub zfs_cgi {
 		"--vertical-label=bytes",
 		"--width=$width",
 		"--height=$height",
+		@extra,
 		@riglim,
 		$zoom,
 		@{$cgi->{version12}},
@@ -1081,6 +1197,7 @@ sub zfs_cgi {
 			"--vertical-label=bytes",
 			"--width=$width",
 			"--height=$height",
+			@extra,
 			@riglim,
 			$zoom,
 			@{$cgi->{version12}},
@@ -1131,4 +1248,41 @@ sub zfs_cgi {
 	return @output;
 }
 
+# Turn readable numbers back into integers, like 1M -> 1048576
+sub zfs_uglify_numbers {
+	my (@numbers) = @_;     
+				
+	my $mult = 1;
+	my $numstr = '';
+	my $num = 0;
+	my $unit = '';
+	my $ignore = '';
+	my @answers = ();
+	 
+	foreach $numstr (@numbers) {
+		($num, $ignore ,$unit) = ($numstr =~ m/(\d+(\.\d+)?)([BKMGTPEZ]?)/i);
+		$unit = uc($unit);
+		if ($unit eq 'B') {
+			$mult = 1024**0;
+		} elsif ($unit eq 'K') {
+			$mult = 1024**1;
+		} elsif ($unit eq 'M') {
+			$mult = 1024**2;
+		} elsif ($unit eq 'G') {
+			$mult = 1024**3;
+		} elsif ($unit eq 'T') {
+			$mult = 1024**4;
+		} elsif ($unit eq 'P') {
+			$mult = 1024**5;
+		} elsif ($unit eq 'E') {
+			$mult = 1024**6;
+		} elsif ($unit eq 'Z') {
+			$mult = 1024**7;
+		} else {
+			$mult = 1024**0;
+		}
+		push(@answers, int($num * $mult));
+	}
+	return @answers;
+}
 1;
